@@ -1,5 +1,5 @@
 import cv2
-from time import sleep
+
 
 class Webcam:
     def __init__(self):
@@ -14,3 +14,10 @@ class Webcam:
     def close(self):
         self.cap.release()
 
+
+
+def check_webcam_permissions():
+    w = Webcam()
+    w.shot()
+    w.close()
+
